@@ -40,7 +40,7 @@ void LSfree(LS* p);
 LS* LSalloc(int m);
 LS* periodogram(const double* t, const double* y, int npts,
 		double over, double hifac);
-int periodogram_simple(const double* tobs, const double* yobs, int npts, double over, double hifac, double *  freqs[]  , double *  Pn[]   ) ;
+int periodogram_simple(const double* tobs, const double* yobs, int npts, double over, double hifac, double *  freqs  , double *  Pn   ) ;
 
 double probability(double Pn, int npts, int nfreqs, double over);
 
