@@ -26,7 +26,14 @@
 #include <complex.h>
 #include <stdbool.h>
 
-void nfft(const double* t, const double* y, int n, int m, double complex * d);
+extern void cnfft(const double* t, const double complex * y, int n, int m,  double complex * d ) ;
+extern void rnfft(const double* t, const double* y, int n, int m,  double complex * d ) ;
+extern void rdft(const double* t, const double* y,  int n, const double *f, int m, int dir ,  double complex * d ) ;
+extern void cdft(const double* t, const double complex * y,  int n, const double *f, int m, int dir ,  double complex * d ) ;
+
+
+
+void nfft(const double* t, const double* y, int n, int m,  double complex * d) ;
 
 
 #endif /* !NFFT_H */
