@@ -4,7 +4,6 @@ import matplotlib.pyplot as plt
 import math
 
 
-
 # sampling
 dt=1.
 
@@ -25,10 +24,24 @@ hifac = 1.
 ofac = 1.
 sig = 1
 
+seed = 143554
+
+np.random.seed(seed)
+
 y = np.random.randn((n))*sig + a0*np.cos(2.*math.pi * nu0 * t)   
-    
+
+data = np.zeros((n,2))
+data[:,0] = t
+data[:,1] = y
+np.savetxt('test_data.txt',data)
+
+
+
 (f,p) = period(t,y,ofac,hifac)
 
+
+
+
 plt.clf()
 plt.plot(f,p)
 plt.loglog()
