@@ -31,7 +31,7 @@ char *xstrdup(const char *s);
 double xstrtod(const char *s);
 long xstrtol(const char *s);
 double centerData(int n0, double *y, double *var);
-void reduce(double* t, int npts, double oversampling);
+extern void reduce(double* t, int npts, double oversampling);
 void meanAndVariance(int n, const double* y, double* mean, double* variance);
 
 #ifdef BENCHMARK
